==> v21.04.tar.gz: bookstack/resources/lang/da/common.php <==
<?php
/**
 * Common elements found throughout many areas of BookStack.
 */
return [

    // Buttons
    'cancel' => 'Annuller',
    'confirm' => 'Bekræft',
    'back' => 'Tilbage',
    'save' => 'Gem',
    'continue' => 'Fortsæt',
    'select' => 'Vælg',
    'toggle_all' => 'Vælg/Fravælg alle',
    'more' => 'Mere',

    // Form Labels
    'name' => 'Navn',
    'description' => 'Beskrivelse',
    'role' => 'Rolle',
    'cover_image' => 'Coverbillede',
    'cover_image_description' => 'Dette billede skal være omtrent 440x250px.',
    
    // Actions
    'actions' => 'Handlinger',
    'view' => 'Vis',
    'view_all' => 'Vis alle',
    'create' => 'Opret',
    'update' => 'Opdater',
    'edit' => 'Rediger',
    'sort' => 'Sorter',
    'move' => 'Flyt',
    'copy' => 'Kopier',
    'reply' => 'Besvar',
    'delete' => 'Slet',
    'delete_confirm' => 'Confirm Deletion',
    'search' => 'Søg',
    'search_clear' => 'Ryd søgning',
    'reset' => 'Nulstil',
    'remove' => 'Fjern',
    'add' => 'Tilføj',
    'fullscreen' => 'Fuld skærm',

    // Sort Options
    'sort_options' => 'Sorteringsindstillinger',
    'sort_direction_toggle' => 'Sorteringsretning',
    'sort_ascending' => 'Sorter stigende',
    'sort_descending' => 'Sorter faldende',
    'sort_name' => 'Navn',
    'sort_default' => 'Default',
    'sort_created_at' => 'Oprettelsesdato',
    'sort_updated_at' => 'Opdateringsdato',

    // Misc
    'deleted_user' => 'Slettet bruger',
    'no_activity' => 'Ingen aktivitet at vise',
    'no_items' => 'Intet indhold tilgængeligt',
    'back_to_top' => 'Tilbage til toppen',
    'toggle_details' => 'Vis/skjul detaljer',
    'toggle_thumbnails' => 'Vis/skjul miniaturer',
    'details' => 'Detaljer',
    'grid_view' => 'Gittervisning',
    'list_view' => 'Listevisning',
    'default' => 'Standard',
    'breadcrumb' => 'Brødkrumme',

    // Header
    'profile_menu' => 'Profilmenu',
    'view_profile' => 'Vis profil',
    'edit_profile' => 'Redigér Profil',
    'dark_mode' => 'Mørk tilstand',
    'light_mode' => 'Lys tilstand',

    // Layout tabs
    'tab_info' => 'Info',
    'tab_content' => 'Indhold',

    // Email Content
    'email_action_help' => 'Hvis du har problemer med at trykke på ":actionText" knappen, prøv at kopiere og indsætte linket herunder ind i din webbrowser:',
    'email_rights' => 'Alle rettigheder forbeholdes',

    // Footer Link Options
    // Not directly used but available for convenience to users.
    'privacy_policy' => 'Privacy Policy',
    'terms_of_service' => 'Terms of Service',
];

==> v21.05.tar.gz: bookstack/resources/lang/da/common.php <==
<?php
/**
 * Common elements found throughout many areas of BookStack.
 */
return [

    // Buttons
    'cancel' => 'Annuller',
    'confirm' => 'Bekræft',
    'back' => 'Tilbage',
    'save' => 'Gem',
    'continue' => 'Fortsæt',
    'select' => 'Vælg',
    'toggle_all' => 'Vælg/Fravælg alle',
    'more' => 'Mere',

    // Form Labels
    'name' => 'Navn',
    'description' => 'Beskrivelse',
    'role' => 'Rolle',
    'cover_image' => 'Coverbillede',
    'cover_image_description' => 'Dette billede skal være omtrent 440x250px.',
    
    // Actions
    'actions' => 'Handlinger',
    'view' => 'Vis',
    'view_all' => 'Vis alle',
    'create' => 'Opret',
    'update' => 'Opdater',
    'edit' => 'Rediger',
    'sort' => 'Sorter',
    'move' => 'Flyt',
    'copy' => 'Kopier',
    'reply' => 'Besvar',
    'delete' => 'Slet',
    'delete_confirm' => 'Bekræft sletning',
    'search' => 'Søg',
    'search_clear' => 'Ryd søgning',
    'reset' => 'Nulstil',
    'remove' => 'Fjern',
    'add' => 'Tilføj',
    'fullscreen' => 'Fuld skærm',
    'favourite' => 'Favourite',
    'unfavourite' => 'Unfavourite',
    'next' => 'Next',
    'previous' => 'Previous',

    // Sort Options
    'sort_options' => 'Sorteringsindstillinger',
    'sort_direction_toggle' => 'Sorteringsretning',
    'sort_ascending' => 'Sorter stigende',
    'sort_descending' => 'Sorter faldende',
    'sort_name' => 'Navn',
    'sort_default' => 'Standard',
    'sort_created_at' => 'Oprettelsesdato',
    'sort_updated_at' => 'Opdateringsdato',

    // Misc
    'deleted_user' => 'Slettet bruger',
    'no_activity' => 'Ingen aktivitet at vise',
    'no_items' => 'Intet indhold tilgængeligt',
    'back_to_top' => 'Tilbage til toppen',
    'toggle_details' => 'Vis/skjul detaljer',
    'toggle_thumbnails' => 'Vis/skjul miniaturer',
    'details' => 'Detaljer',
    'grid_view' => 'Gittervisning',
    'list_view' => 'Listevisning',
    'default' => 'Standard',
    'breadcrumb' => 'Brødkrumme',

    // Header
    'header_menu_expand' => 'Udvid header menu',
    'profile_menu' => 'Profilmenu',
    'view_profile' => 'Vis profil',
    'edit_profile' => 'Redigér Profil',
    'dark_mode' => 'Mørk tilstand',
    'light_mode' => 'Lys tilstand',

    // Layout tabs
    'tab_info' => 'Info',
    'tab_info_label' => 'Faneblad: Vis sekundær information',
    'tab_content' => 'Indhold',
    'tab_content_label' => 'Faneblad: Vis primær indhold',

    // Email Content
    'email_action_help' => 'Hvis du har problemer med at trykke på ":actionText" knappen, prøv at kopiere og indsætte linket herunder ind i din webbrowser:',
    'email_rights' => 'Alle rettigheder forbeholdes',

    // Footer Link Options
    // Not directly used but available for convenience to users.
    'privacy_policy' => 'Privatlivspolitik',
    'terms_of_service' => 'Tjenestevilkår',
];
